AutocompletionRequest class

Available extensions
Annotations
  • @JS.new()
  • @anonymous

Constructors

AutocompletionRequest()
factory

Properties

bounds ↔ LatLngBounds?
getter/setter pair
componentRestrictions ↔ ComponentRestrictions?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
input ↔ String?
getter/setter pair
location ↔ LatLng?
getter/setter pair
offset ↔ num?
getter/setter pair
origin ↔ LatLng?
getter/setter pair
radius ↔ num?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionToken ↔ AutocompleteSessionToken?
getter/setter pair
types ↔ List<String?>?

Available on AutocompletionRequest, provided by the AutocompletionRequest$Ext extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited